#' @useDynLib hibayes, .registration=TRUE
NULL
#> NULL

#' @import bigmemory
NULL

#' @import Matrix
NULL

#' @import methods
NULL

#' @import CMplot
NULL

#' @importFrom CMplot CMplot
#' @export
CMplot::CMplot

#' @importFrom stringr str_extract_all
NULL
#' @importFrom stringr str_replace_all
NULL
#' @importFrom stringr str_detect
NULL

#' @importFrom stats na.omit
NULL
#' @importFrom stats sd
NULL
#' @importFrom stats runif
NULL
#' @importFrom stats rnorm
NULL
#' @importFrom stats rgamma
NULL
#' @importFrom stats rchisq
NULL
#' @importFrom stats rbeta
NULL
#' @importFrom stats rt
NULL
#' @importFrom stats rcauchy
NULL
#' @importFrom stats rexp
NULL
#' @importFrom stats printCoefmat
NULL
#' @importFrom stats model.frame
NULL
#' @importFrom stats model.matrix
NULL

#' @importFrom methods new
#' @export
methods::new

#' @importFrom utils packageVersion
#' @export
utils::packageVersion

#' @importFrom utils read.delim
#' @export
utils::read.delim

#' @importFrom utils read.table
#' @export
utils::read.table

#' @importFrom utils write.table
#' @export
utils::write.table

#' @exportS3Method summary blrMod
NULL

#' @exportS3Method print summary.blrMod
NULL
